/*
 * #%L
 * JSQLParser library
 * %%
 * Copyright (C) 2004 - 2013 JSQLParser
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 2.1 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.sf.jsqlparser.expression.operators.relational;

import net.sf.jsqlparser.expression.BinaryExpression;
import static net.sf.jsqlparser.expression.operators.relational.SupportsOldOracleJoinSyntax.ORACLE_PRIOR_START;

public abstract class OldOracleJoinBinaryExpression extends BinaryExpression implements SupportsOldOracleJoinSyntax {

    private int oldOracleJoinSyntax = NO_ORACLE_JOIN;
	
	private int oraclePriorPosition = NO_ORACLE_PRIOR;

	@Override
    public void setOldOracleJoinSyntax(int oldOracleJoinSyntax) {
        this.oldOracleJoinSyntax = oldOracleJoinSyntax;
        if (oldOracleJoinSyntax < 0 || oldOracleJoinSyntax > 2) {
            throw new IllegalArgumentException("unknown join type for oracle found (type=" + oldOracleJoinSyntax + ")");
        }
    }

    @Override
    public String toString() {
        return (isNot() ? "NOT " : "") 
				+ (oraclePriorPosition == ORACLE_PRIOR_START ? "PRIOR " : "")
				+ getLeftExpression() 
				+ (oldOracleJoinSyntax == ORACLE_JOIN_RIGHT ? "(+)" : "") + " " 
				+ getStringExpression() + " " 
				+ (oraclePriorPosition == ORACLE_PRIOR_END ? "PRIOR " : "")
				+ getRightExpression() 
				+ (oldOracleJoinSyntax == ORACLE_JOIN_LEFT ? "(+)" : "");
    }

	@Override
    public int getOldOracleJoinSyntax() {
        return oldOracleJoinSyntax;
    }

	@Override
	public int getOraclePriorPosition() {
		return oraclePriorPosition;
	}

	@Override
	public void setOraclePriorPosition(int oraclePriorPosition) {
		this.oraclePriorPosition = oraclePriorPosition;
	}
}
